/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM
 * d:/Mozilla/mozilla/caps/idl/nsIPrincipal.idl
 */

package org.mozilla.interfaces;

/**
 * WARNING!! The JEP needs to call GetOrigin()  to support
 * JavaScript-to-Java LiveConnect.  So every change to the  nsIPrincipal
 * interface (big enough to change its IID) also breaks JavaScript-to-Java
 * LiveConnect on mac.
 *
 * If you REALLY have to change this interface, please mark your bug as
 * blocking bug 293973.
 */
public interface nsIPrincipal extends nsISerializable {

  String NS_IPRINCIPAL_IID =
    "{b8268b9a-2403-44ed-81e3-614075c92034}";

  /**
     * Values of capabilities for each principal. Order is
     * significant: if an operation is performed on a set
     * of capabilities, the minimum is computed.
     */
  short ENABLE_DENIED = 1;

  short ENABLE_UNKNOWN = 2;

  short ENABLE_WITH_USER_PERMISSION = 3;

  short ENABLE_GRANTED = 4;

  /**
     * Returns the security preferences associated with this principal.
     * prefBranch will be set to the pref branch to which these preferences
     * pertain.  id is a pseudo-unique identifier, pertaining to either the
     * fingerprint or the origin.  subjectName is a name that identifies the
     * entity this principal represents (may be empty).  grantedList and
     * deniedList are space-separated lists of capabilities which were
     * explicitly granted or denied by a pref.  isTrusted is a boolean that
     * indicates whether this is a codebaseTrusted certificate.
     */
  void getPreferences(String[] prefBranch, String[] id, String[] subjectName, String[] grantedList, String[] deniedList, boolean[] isTrusted);

  /**
     * Returns whether the other principal is equivalent to this principal.
     * Principals are considered equal if they are the same principal,
     * they have the same origin, or have the same certificate fingerprint ID
     */
  boolean _equals(nsIPrincipal other);

  /**
     * Returns a hash value for the principal.
     */
  long getHashValue();

  /**
     * Returns the JS equivalent of the principal.
     * @see JSPrincipals.h
     */
  long getJSPrincipals(long cx);

  /**
     * The domain security policy of the principal.
     */
  long getSecurityPolicy();

  /**
     * The domain security policy of the principal.
     */
  void setSecurityPolicy(long aSecurityPolicy);

  short canEnableCapability(String capability);

  void setCanEnableCapability(String capability, short canEnable);

  boolean isCapabilityEnabled(String capability, long annotation);

  void enableCapability(String capability, long[] annotation);

  void revertCapability(String capability, long[] annotation);

  void disableCapability(String capability, long[] annotation);

  /**
     * The codebase URI to which this principal pertains.  This is
     * generally the document URI.
     */
  nsIURI getURI();

  /**
     * The domain URI to which this principal pertains.
     * This is congruent with HTMLDocument.domain, and may be null.
     * Setting this has no effect on the URI.
     */
  nsIURI getDomain();

  /**
     * The domain URI to which this principal pertains.
     * This is congruent with HTMLDocument.domain, and may be null.
     * Setting this has no effect on the URI.
     */
  void setDomain(nsIURI aDomain);

  /**
     * The origin of this principal's codebase URI.
     * An origin is defined as: scheme + host + port.
     */
  String getOrigin();

  /**
     * Whether this principal is associated with a certificate.
     */
  boolean getHasCertificate();

  /**
     * The fingerprint ID of this principal's certificate.
     * Throws if there is no certificate associated with this principal.
     */
  String getFingerprint();

  /**
     * The pretty name for the certificate.  This sort of (but not really)
     * identifies the subject of the certificate (the entity that stands behind
     * the certificate).  Note that this may be empty; prefer to get the
     * certificate itself and get this information from it, since that may
     * provide more information.
     *
     * Throws if there is no certificate associated with this principal.
     */
  String getPrettyName();

  /**
     * Returns whether the other principal is equal to or weaker than this
     * principal.  Principals are equal if they are the same object, they
     * have the same origin, or they have the same certificate ID.
     *
     * Thus a principal always subsumes itself.
     *
     * The system principal subsumes itself and all other principals.
     *
     * A null principal (corresponding to an unknown, hence assumed minimally
     * privileged, security context) is not equal to any other principal
     * (including other null principals), and therefore does not subsume
     * anything but itself.
     *
     * Both codebase and certificate principals are subsumed by the system
     * principal, but no codebase or certificate principal yet subsumes any
     * other codebase or certificate principal.  This may change in a future
     * release; note that nsIPrincipal is unfrozen, not slated to be frozen.
     *
     * XXXbz except see bug 147145!
     *
     * Note for the future: Perhaps we should consider a certificate principal
     * for a given URI subsuming a codebase principal for the same URI?  Not
     * sure what the immediate benefit would be, but I think the setup could
     * make some code (e.g. MaybeDowngradeToCodebase) clearer.
     */
  boolean subsumes(nsIPrincipal other);

  /**
     * Checks whether this principal is allowed to load the network resource
     * located at the given URI under the same-origin policy. This means that
     * codebase principals are only allowed to load resources from the same
     * domain, the system principal is allowed to load anything, and null
     * principals are not allowed to load anything.
     *
     * If the load is allowed this function does nothing. If the load is not
     * allowed the function throws NS_ERROR_DOM_BAD_URI.
     *
     * NOTE: Other policies might override this, such as the Access-Control
     *       specification.
     * NOTE: The 'domain' attribute has no effect on the behaviour of this
     *       function.
     *
     *
     * @param uri    The URI about to be loaded.
     * @param report If true, will report a warning to the console service
     *               if the load is not allowed.
     * @throws NS_ERROR_DOM_BAD_URI if the load is not allowed.
     */
  void checkMayLoad(nsIURI uri, boolean report);

  /**
     * The subject name for the certificate.  This actually identifies the
     * subject of the certificate.  This may well not be a string that would
     * mean much to a typical user on its own (e.g. it may have a number of
     * different names all concatenated together with some information on what
     * they mean in between).
     *
     * Throws if there is no certificate associated with this principal.
     */
  String getSubjectName();

  /**
     * The certificate associated with this principal, if any.  If there isn't
     * one, this will return null.  Getting this attribute never throws.
     */
  nsISupports getCertificate();

}